# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ModelId(str, Enum):
    """
    ModelId
    """

    """
    allowed enum values
    """
    AI21_SLASH_JAMBA_MINUS_LARGE_MINUS_1_MINUS_5_MINUS_2024_MINUS_08_MINUS_22 = 'ai21/jamba-large-1-5-2024-08-22'
    AI21_SLASH_JAMBA_MINUS_LARGE_MINUS_1_MINUS_6_MINUS_2025_MINUS_03_MINUS_06 = 'ai21/jamba-large-1-6-2025-03-06'
    AI21_SLASH_JAMBA_MINUS_LARGE_MINUS_1_MINUS_7_MINUS_2025_MINUS_07_MINUS_03 = 'ai21/jamba-large-1-7-2025-07-03'
    AI21_SLASH_JAMBA_MINUS_MINI_MINUS_1_MINUS_5_MINUS_2024_MINUS_08_MINUS_22 = 'ai21/jamba-mini-1-5-2024-08-22'
    AI21_SLASH_JAMBA_MINUS_MINI_MINUS_1_MINUS_6_MINUS_2025_MINUS_03_MINUS_06 = 'ai21/jamba-mini-1-6-2025-03-06'
    AI21_SLASH_JAMBA_MINUS_MINI_MINUS_1_MINUS_7_MINUS_2025_MINUS_07_MINUS_03 = 'ai21/jamba-mini-1-7-2025-07-03'
    AMAZON_SLASH_NOVA_MINUS_CANVAS = 'amazon/nova-canvas'
    AMAZON_SLASH_NOVA_MINUS_LITE_MINUS_1_MINUS_0_MINUS_2024_MINUS_12_MINUS_04 = 'amazon/nova-lite-1-0-2024-12-04'
    AMAZON_SLASH_NOVA_MINUS_MICRO_MINUS_1_MINUS_0_MINUS_2024_MINUS_12_MINUS_04 = 'amazon/nova-micro-1-0-2024-12-04'
    AMAZON_SLASH_NOVA_MINUS_PREMIER_MINUS_2025_MINUS_04_MINUS_30 = 'amazon/nova-premier-2025-04-30'
    AMAZON_SLASH_NOVA_MINUS_PRO_MINUS_1_MINUS_0_MINUS_2024_MINUS_12_MINUS_04 = 'amazon/nova-pro-1-0-2024-12-04'
    AMAZON_SLASH_NOVA_MINUS_REEL = 'amazon/nova-reel'
    AMAZON_SLASH_NOVA_MINUS_SONIC = 'amazon/nova-sonic'
    ANTHROPIC_SLASH_CLAUDE_MINUS_1_MINUS_0_MINUS_2023_MINUS_03_MINUS_14 = 'anthropic/claude-1-0-2023-03-14'
    ANTHROPIC_SLASH_CLAUDE_MINUS_1_MINUS_1 = 'anthropic/claude-1-1'
    ANTHROPIC_SLASH_CLAUDE_MINUS_1_MINUS_2 = 'anthropic/claude-1-2'
    ANTHROPIC_SLASH_CLAUDE_MINUS_1_MINUS_3 = 'anthropic/claude-1-3'
    ANTHROPIC_SLASH_CLAUDE_MINUS_2_MINUS_0_MINUS_2023_MINUS_07_MINUS_12 = 'anthropic/claude-2-0-2023-07-12'
    ANTHROPIC_SLASH_CLAUDE_MINUS_2_MINUS_1_MINUS_2023_MINUS_11_MINUS_22 = 'anthropic/claude-2-1-2023-11-22'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_5_MINUS_HAIKU_MINUS_2024_MINUS_11_MINUS_04 = 'anthropic/claude-3-5-haiku-2024-11-04'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_5_MINUS_SONNET_MINUS_2024_MINUS_06_MINUS_21 = 'anthropic/claude-3-5-sonnet-2024-06-21'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_5_MINUS_SONNET_MINUS_2024_MINUS_10_MINUS_22 = 'anthropic/claude-3-5-sonnet-2024-10-22'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_7_MINUS_SONNET_MINUS_2025_MINUS_02_MINUS_24 = 'anthropic/claude-3-7-sonnet-2025-02-24'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_HAIKU_MINUS_2024_MINUS_03_MINUS_13 = 'anthropic/claude-3-haiku-2024-03-13'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_OPUS_MINUS_2024_MINUS_03_MINUS_04 = 'anthropic/claude-3-opus-2024-03-04'
    ANTHROPIC_SLASH_CLAUDE_MINUS_3_MINUS_SONNET_MINUS_2024_MINUS_03_MINUS_04 = 'anthropic/claude-3-sonnet-2024-03-04'
    ANTHROPIC_SLASH_CLAUDE_MINUS_HAIKU_MINUS_4_MINUS_5_MINUS_2025_MINUS_10_MINUS_15 = 'anthropic/claude-haiku-4-5-2025-10-15'
    ANTHROPIC_SLASH_CLAUDE_MINUS_INSTANT_MINUS_1_MINUS_0_MINUS_2023_MINUS_03_MINUS_14 = 'anthropic/claude-instant-1-0-2023-03-14'
    ANTHROPIC_SLASH_CLAUDE_MINUS_INSTANT_MINUS_1_MINUS_1 = 'anthropic/claude-instant-1-1'
    ANTHROPIC_SLASH_CLAUDE_MINUS_INSTANT_MINUS_1_MINUS_2_MINUS_2023_MINUS_08_MINUS_09 = 'anthropic/claude-instant-1-2-2023-08-09'
    ANTHROPIC_SLASH_CLAUDE_MINUS_OPUS_MINUS_4_MINUS_1_MINUS_2025_MINUS_08_MINUS_05 = 'anthropic/claude-opus-4-1-2025-08-05'
    ANTHROPIC_SLASH_CLAUDE_MINUS_OPUS_MINUS_4_MINUS_2025_MINUS_05_MINUS_21 = 'anthropic/claude-opus-4-2025-05-21'
    ANTHROPIC_SLASH_CLAUDE_MINUS_OPUS_MINUS_4_MINUS_5_MINUS_2025_MINUS_11_MINUS_24 = 'anthropic/claude-opus-4-5-2025-11-24'
    ANTHROPIC_SLASH_CLAUDE_MINUS_SONNET_MINUS_4_MINUS_2025_MINUS_05_MINUS_21 = 'anthropic/claude-sonnet-4-2025-05-21'
    ANTHROPIC_SLASH_CLAUDE_MINUS_SONNET_MINUS_4_MINUS_5_MINUS_2025_MINUS_09_MINUS_29 = 'anthropic/claude-sonnet-4-5-2025-09-29'
    BAIDU_SLASH_ERNIE_MINUS_4_MINUS_5_MINUS_21B_MINUS_A3B = 'baidu/ernie-4-5-21b-a3b'
    BAIDU_SLASH_ERNIE_MINUS_4_MINUS_5_MINUS_21B_MINUS_A3B_MINUS_THINKING = 'baidu/ernie-4-5-21b-a3b-thinking'
    BAIDU_SLASH_ERNIE_MINUS_4_MINUS_5_MINUS_300B_MINUS_A47B = 'baidu/ernie-4-5-300b-a47b'
    BAIDU_SLASH_ERNIE_MINUS_4_MINUS_5_MINUS_VL_MINUS_28B_MINUS_A3B = 'baidu/ernie-4-5-vl-28b-a3b'
    BAIDU_SLASH_ERNIE_MINUS_4_MINUS_5_MINUS_VL_MINUS_424B_MINUS_A47B = 'baidu/ernie-4-5-vl-424b-a47b'
    BAIDU_SLASH_QIANFAN_MINUS_VL_MINUS_3B = 'baidu/qianfan-vl-3b'
    BAIDU_SLASH_QIANFAN_MINUS_VL_MINUS_70B = 'baidu/qianfan-vl-70b'
    BAIDU_SLASH_QIANFAN_MINUS_VL_MINUS_8B = 'baidu/qianfan-vl-8b'
    BYTEDANCE_SLASH_SEED_MINUS_CODER_MINUS_8B_MINUS_INSTRUCT = 'bytedance/seed-coder-8b-instruct'
    BYTEDANCE_SLASH_SEED_MINUS_CODER_MINUS_8B_MINUS_REASONING = 'bytedance/seed-coder-8b-reasoning'
    BYTEDANCE_SLASH_SEED_MINUS_OSS_MINUS_36B_MINUS_INSTRUCT = 'bytedance/seed-oss-36b-instruct'
    COHERE_SLASH_C4AI_MINUS_AYA_MINUS_EXPANSE_MINUS_32B = 'cohere/c4ai-aya-expanse-32b'
    COHERE_SLASH_C4AI_MINUS_AYA_MINUS_EXPANSE_MINUS_8B = 'cohere/c4ai-aya-expanse-8b'
    COHERE_SLASH_C4AI_MINUS_AYA_MINUS_VISION_MINUS_32B = 'cohere/c4ai-aya-vision-32b'
    COHERE_SLASH_C4AI_MINUS_AYA_MINUS_VISION_MINUS_8B = 'cohere/c4ai-aya-vision-8b'
    COHERE_SLASH_COMMAND = 'cohere/command'
    COHERE_SLASH_COMMAND_MINUS_A_MINUS_2025_MINUS_03_MINUS_13 = 'cohere/command-a-2025-03-13'
    COHERE_SLASH_COMMAND_MINUS_A_MINUS_REASONING_MINUS_2025_MINUS_08_MINUS_21 = 'cohere/command-a-reasoning-2025-08-21'
    COHERE_SLASH_COMMAND_MINUS_A_MINUS_TRANSLATE_MINUS_2025_MINUS_08_MINUS_28 = 'cohere/command-a-translate-2025-08-28'
    COHERE_SLASH_COMMAND_MINUS_A_MINUS_VISION_MINUS_2025_MINUS_07_MINUS_31 = 'cohere/command-a-vision-2025-07-31'
    COHERE_SLASH_COMMAND_MINUS_LIGHT = 'cohere/command-light'
    COHERE_SLASH_COMMAND_MINUS_R_MINUS_2024_MINUS_03_MINUS_11 = 'cohere/command-r-2024-03-11'
    COHERE_SLASH_COMMAND_MINUS_R_MINUS_2024_MINUS_08_MINUS_30 = 'cohere/command-r-2024-08-30'
    COHERE_SLASH_COMMAND_MINUS_R_MINUS_7B_MINUS_2024_MINUS_12_MINUS_13 = 'cohere/command-r-7b-2024-12-13'
    COHERE_SLASH_COMMAND_MINUS_R_PLUS_MINUS_2024_MINUS_04_MINUS_04 = 'cohere/command-r+-2024-04-04'
    COHERE_SLASH_COMMAND_MINUS_R_PLUS_MINUS_2024_MINUS_08_MINUS_30 = 'cohere/command-r+-2024-08-30'
    COHERE_SLASH_EMBED_MINUS_ENGLISH_MINUS_LIGHT_MINUS_V2_MINUS_0 = 'cohere/embed-english-light-v2-0'
    COHERE_SLASH_EMBED_MINUS_ENGLISH_MINUS_LIGHT_MINUS_V3 = 'cohere/embed-english-light-v3'
    COHERE_SLASH_EMBED_MINUS_ENGLISH_MINUS_V2_MINUS_0 = 'cohere/embed-english-v2-0'
    COHERE_SLASH_EMBED_MINUS_ENGLISH_MINUS_V3 = 'cohere/embed-english-v3'
    COHERE_SLASH_EMBED_MINUS_MULTILINGUAL_MINUS_LIGHT_MINUS_V3 = 'cohere/embed-multilingual-light-v3'
    COHERE_SLASH_EMBED_MINUS_MULTILINGUAL_MINUS_V2_MINUS_0 = 'cohere/embed-multilingual-v2-0'
    COHERE_SLASH_EMBED_MINUS_MULTILINGUAL_MINUS_V3 = 'cohere/embed-multilingual-v3'
    COHERE_SLASH_EMBED_MINUS_V4 = 'cohere/embed-v4'
    COHERE_SLASH_RERANK_MINUS_MULTILINGUAL_MINUS_V3 = 'cohere/rerank-multilingual-v3'
    COHERE_SLASH_RERANK_MINUS_V3_MINUS_5 = 'cohere/rerank-v3-5'
    COHERE_SLASH_RERENK_MINUS_ENGLISH_MINUS_V3 = 'cohere/rerenk-english-v3'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_CODER_MINUS_V2_MINUS_2024_MINUS_06_MINUS_14 = 'deepseek/deepseek-coder-v2-2024-06-14'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_CODER_MINUS_V2_MINUS_2024_MINUS_07_MINUS_24 = 'deepseek/deepseek-coder-v2-2024-07-24'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_OCR_MINUS_2025_MINUS_10_MINUS_20 = 'deepseek/deepseek-ocr-2025-10-20'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_R1_MINUS_2025_MINUS_01_MINUS_20 = 'deepseek/deepseek-r1-2025-01-20'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_R1_MINUS_2025_MINUS_05_MINUS_28 = 'deepseek/deepseek-r1-2025-05-28'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_R1_MINUS_LITE_MINUS_PREVIEW = 'deepseek/deepseek-r1-lite-preview'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V2_MINUS_2024_MINUS_05_MINUS_17 = 'deepseek/deepseek-v2-2024-05-17'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V2_MINUS_2024_MINUS_06_MINUS_28 = 'deepseek/deepseek-v2-2024-06-28'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V2_MINUS_5 = 'deepseek/deepseek-v2-5'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V2_MINUS_5_MINUS_2024_MINUS_05_MINUS_08 = 'deepseek/deepseek-v2-5-2024-05-08'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V3_MINUS_1 = 'deepseek/deepseek-v3-1'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V3_MINUS_1_MINUS_TERMINUS_MINUS_2025_MINUS_09_MINUS_22 = 'deepseek/deepseek-v3-1-terminus-2025-09-22'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V3_MINUS_2_MINUS_2025_MINUS_09_MINUS_29 = 'deepseek/deepseek-v3-2-2025-09-29'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V3_MINUS_2024_MINUS_12_MINUS_25 = 'deepseek/deepseek-v3-2024-12-25'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_V3_MINUS_2025_MINUS_03_MINUS_25 = 'deepseek/deepseek-v3-2025-03-25'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_VL2_MINUS_2024_MINUS_12_MINUS_13 = 'deepseek/deepseek-vl2-2024-12-13'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_VL2_MINUS_SMALL_MINUS_2024_MINUS_12_MINUS_13 = 'deepseek/deepseek-vl2-small-2024-12-13'
    DEEPSEEK_SLASH_DEEPSEEK_MINUS_VL2_MINUS_TINY_MINUS_2024_MINUS_12_MINUS_13 = 'deepseek/deepseek-vl2-tiny-2024-12-13'
    GOOGLE_SLASH_EMBEDDING_MINUS_001_MINUS_2023_MINUS_12_MINUS_13 = 'google/embedding-001-2023-12-13'
    GOOGLE_SLASH_EMBEDDING_MINUS_GECKO_MINUS_001_MINUS_2023_MINUS_12_MINUS_13 = 'google/embedding-gecko-001-2023-12-13'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_0_MINUS_NANO_MINUS_2023_MINUS_12_MINUS_06 = 'google/gemini-1-0-nano-2023-12-06'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_0_MINUS_PRO_MINUS_2023_MINUS_12_MINUS_06 = 'google/gemini-1-0-pro-2023-12-06'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_0_MINUS_ULTRA_MINUS_2023_MINUS_12_MINUS_06 = 'google/gemini-1-0-ultra-2023-12-06'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_FLASH_MINUS_001_MINUS_2024_MINUS_05_MINUS_23 = 'google/gemini-1-5-flash-001-2024-05-23'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_FLASH_MINUS_002_MINUS_2024_MINUS_09_MINUS_24 = 'google/gemini-1-5-flash-002-2024-09-24'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_FLASH_MINUS_8B_MINUS_2024_MINUS_03_MINUS_15 = 'google/gemini-1-5-flash-8b-2024-03-15'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_FLASH_MINUS_8B_MINUS_EXP_MINUS_2024_MINUS_08_MINUS_27 = 'google/gemini-1-5-flash-8b-exp-2024-08-27'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_FLASH_MINUS_8B_MINUS_EXP_MINUS_2024_MINUS_09_MINUS_24 = 'google/gemini-1-5-flash-8b-exp-2024-09-24'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_PRO_MINUS_001_MINUS_2024_MINUS_05_MINUS_23 = 'google/gemini-1-5-pro-001-2024-05-23'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_PRO_MINUS_002_MINUS_2024_MINUS_09_MINUS_24 = 'google/gemini-1-5-pro-002-2024-09-24'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_PRO_MINUS_EXP_MINUS_2024_MINUS_08_MINUS_01 = 'google/gemini-1-5-pro-exp-2024-08-01'
    GOOGLE_SLASH_GEMINI_MINUS_1_MINUS_5_MINUS_PRO_MINUS_EXP_MINUS_2024_MINUS_08_MINUS_27 = 'google/gemini-1-5-pro-exp-2024-08-27'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_2025_MINUS_02_MINUS_05 = 'google/gemini-2-0-flash-2025-02-05'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_EXP = 'google/gemini-2-0-flash-exp'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_EXP_MINUS_IMAGE_MINUS_GENERATION = 'google/gemini-2-0-flash-exp-image-generation'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_LITE_MINUS_2025_MINUS_02_MINUS_05 = 'google/gemini-2-0-flash-lite-2025-02-05'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_LIVE_MINUS_001_MINUS_2025_MINUS_04_MINUS_09 = 'google/gemini-2-0-flash-live-001-2025-04-09'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_PREVIEW_MINUS_IMAGE_MINUS_GENERATION_MINUS_2025_MINUS_05_MINUS_07 = 'google/gemini-2-0-flash-preview-image-generation-2025-05-07'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_THINKING_MINUS_EXP_MINUS_2024_MINUS_12_MINUS_19 = 'google/gemini-2-0-flash-thinking-exp-2024-12-19'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_THINKING_MINUS_EXP_MINUS_2025_MINUS_01_MINUS_21 = 'google/gemini-2-0-flash-thinking-exp-2025-01-21'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_0_MINUS_PRO_MINUS_EXP_MINUS_2025_MINUS_02_MINUS_05 = 'google/gemini-2-0-pro-exp-2025-02-05'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_COMPUTER_MINUS_USE_MINUS_PREVIEW_MINUS_2025_MINUS_10_MINUS_07 = 'google/gemini-2-5-computer-use-preview-2025-10-07'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_EXP_MINUS_NATIVE_MINUS_AUDIO_MINUS_THINKING_MINUS_DIALOG = 'google/gemini-2-5-flash-exp-native-audio-thinking-dialog'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_IMAGE_MINUS_PREVIEW = 'google/gemini-2-5-flash-image-preview'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_LITE_MINUS_PREVIEW_MINUS_2025_MINUS_06_MINUS_17 = 'google/gemini-2-5-flash-lite-preview-2025-06-17'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_LITE_MINUS_PREVIEW_MINUS_2025_MINUS_09_MINUS_25 = 'google/gemini-2-5-flash-lite-preview-2025-09-25'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_NATIVE_MINUS_AUDIO_MINUS_PREVIEW = 'google/gemini-2-5-flash-native-audio-preview'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_2025_MINUS_04_MINUS_17 = 'google/gemini-2-5-flash-preview-2025-04-17'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_2025_MINUS_05_MINUS_20 = 'google/gemini-2-5-flash-preview-2025-05-20'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_2025_MINUS_09_MINUS_25 = 'google/gemini-2-5-flash-preview-2025-09-25'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_NATIVE_MINUS_AUDIO_MINUS_DIALOG = 'google/gemini-2-5-flash-preview-native-audio-dialog'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_TTS = 'google/gemini-2-5-flash-preview-tts'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_PRO_MINUS_EXPERIMENTAL = 'google/gemini-2-5-pro-experimental'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_PRO_MINUS_PREVIEW_MINUS_2025_MINUS_05_MINUS_06 = 'google/gemini-2-5-pro-preview-2025-05-06'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_PRO_MINUS_PREVIEW_MINUS_2025_MINUS_06_MINUS_05 = 'google/gemini-2-5-pro-preview-2025-06-05'
    GOOGLE_SLASH_GEMINI_MINUS_2_MINUS_5_MINUS_PRO_MINUS_PREVIEW_MINUS_TTS = 'google/gemini-2-5-pro-preview-tts'
    GOOGLE_SLASH_GEMINI_MINUS_3_MINUS_0_MINUS_FLASH = 'google/gemini-3-0-flash'
    GOOGLE_SLASH_GEMINI_MINUS_3_MINUS_0_MINUS_FLASH_MINUS_LITE = 'google/gemini-3-0-flash-lite'
    GOOGLE_SLASH_GEMINI_MINUS_3_MINUS_0_MINUS_PRO_MINUS_PREVIEW_MINUS_2025_MINUS_11_MINUS_18 = 'google/gemini-3-0-pro-preview-2025-11-18'
    GOOGLE_SLASH_GEMINI_MINUS_3_MINUS_PRO_MINUS_IMAGE_MINUS_PREVIEW_MINUS_2025_MINUS_11_MINUS_20 = 'google/gemini-3-pro-image-preview-2025-11-20'
    GOOGLE_SLASH_GEMINI_MINUS_DIFFUSION = 'google/gemini-diffusion'
    GOOGLE_SLASH_GEMINI_MINUS_EMBEDDING_MINUS_001_MINUS_2025_MINUS_05_MINUS_20 = 'google/gemini-embedding-001-2025-05-20'
    GOOGLE_SLASH_GEMINI_MINUS_EMBEDDING_MINUS_EXP_MINUS_0307_MINUS_2025_MINUS_03_MINUS_07 = 'google/gemini-embedding-exp-0307-2025-03-07'
    GOOGLE_SLASH_GEMINI_MINUS_EXP_MINUS_1114_MINUS_2024_MINUS_11_MINUS_14 = 'google/gemini-exp-1114-2024-11-14'
    GOOGLE_SLASH_GEMINI_MINUS_EXP_MINUS_1121_MINUS_2024_MINUS_11_MINUS_21 = 'google/gemini-exp-1121-2024-11-21'
    GOOGLE_SLASH_GEMINI_MINUS_EXP_MINUS_1206 = 'google/gemini-exp-1206'
    GOOGLE_SLASH_GEMINI_MINUS_LIVE_MINUS_2_MINUS_5_MINUS_FLASH_MINUS_PREVIEW_MINUS_2025_MINUS_04_MINUS_09 = 'google/gemini-live-2-5-flash-preview-2025-04-09'
    GOOGLE_SLASH_GEMINI_MINUS_ROBOTICS_MINUS_ER_MINUS_1_MINUS_5_MINUS_PREVIEW = 'google/gemini-robotics-er-1-5-preview'
    GOOGLE_SLASH_GEMMA_MINUS_1_MINUS_2B_MINUS_2024_MINUS_02_MINUS_21 = 'google/gemma-1-2b-2024-02-21'
    GOOGLE_SLASH_GEMMA_MINUS_1_MINUS_7B_MINUS_2024_MINUS_02_MINUS_21 = 'google/gemma-1-7b-2024-02-21'
    GOOGLE_SLASH_GEMMA_MINUS_2_MINUS_27B_MINUS_2024_MINUS_06_MINUS_27 = 'google/gemma-2-27b-2024-06-27'
    GOOGLE_SLASH_GEMMA_MINUS_2_MINUS_2B_MINUS_2024_MINUS_07_MINUS_31 = 'google/gemma-2-2b-2024-07-31'
    GOOGLE_SLASH_GEMMA_MINUS_2_MINUS_9B_MINUS_2024_MINUS_06_MINUS_27 = 'google/gemma-2-9b-2024-06-27'
    GOOGLE_SLASH_GEMMA_MINUS_3_MINUS_12B_MINUS_2025_MINUS_03_MINUS_12 = 'google/gemma-3-12b-2025-03-12'
    GOOGLE_SLASH_GEMMA_MINUS_3_MINUS_1B_MINUS_2025_MINUS_03_MINUS_12 = 'google/gemma-3-1b-2025-03-12'
    GOOGLE_SLASH_GEMMA_MINUS_3_MINUS_27B_MINUS_2025_MINUS_03_MINUS_12 = 'google/gemma-3-27b-2025-03-12'
    GOOGLE_SLASH_GEMMA_MINUS_3_MINUS_4B_MINUS_2025_MINUS_03_MINUS_12 = 'google/gemma-3-4b-2025-03-12'
    GOOGLE_SLASH_GEMMA_MINUS_3N_MINUS_E2B = 'google/gemma-3n-e2b'
    GOOGLE_SLASH_GEMMA_MINUS_3N_MINUS_E4B_MINUS_2025_MINUS_05_MINUS_20 = 'google/gemma-3n-e4b-2025-05-20'
    GOOGLE_SLASH_IMAGEN_MINUS_3_MINUS_0_MINUS_GENERATE_MINUS_001 = 'google/imagen-3-0-generate-001'
    GOOGLE_SLASH_IMAGEN_MINUS_3_MINUS_0_MINUS_GENERATE_MINUS_002_MINUS_2025_MINUS_02_MINUS_06 = 'google/imagen-3-0-generate-002-2025-02-06'
    GOOGLE_SLASH_IMAGEN_MINUS_4_MINUS_0_MINUS_FAST_MINUS_GENERATE_MINUS_001 = 'google/imagen-4-0-fast-generate-001'
    GOOGLE_SLASH_IMAGEN_MINUS_4_MINUS_0_MINUS_GENERATE_MINUS_001_MINUS_2025_MINUS_08_MINUS_14 = 'google/imagen-4-0-generate-001-2025-08-14'
    GOOGLE_SLASH_IMAGEN_MINUS_4_MINUS_0_MINUS_ULTRA_MINUS_GENERATE_MINUS_001_MINUS_2025_MINUS_08_MINUS_14 = 'google/imagen-4-0-ultra-generate-001-2025-08-14'
    GOOGLE_SLASH_IMAGEN_MINUS_4_MINUS_PREVIEW = 'google/imagen-4-preview'
    GOOGLE_SLASH_IMAGEN_MINUS_4_MINUS_ULTRA_MINUS_PREVIEW_MINUS_2025_MINUS_08_MINUS_14 = 'google/imagen-4-ultra-preview-2025-08-14'
    GOOGLE_SLASH_LEARNLM_MINUS_1_MINUS_5_MINUS_PRO_MINUS_EXPERIMENTAL = 'google/learnlm-1-5-pro-experimental'
    GOOGLE_SLASH_LEARNLM_MINUS_2_MINUS_0_MINUS_FLASH_MINUS_EXPERIMENTAL = 'google/learnlm-2-0-flash-experimental'
    GOOGLE_SLASH_VEO_MINUS_2_MINUS_2025_MINUS_04_MINUS_09 = 'google/veo-2-2025-04-09'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_0_MINUS_FAST_MINUS_GENERATE_MINUS_PREVIEW_MINUS_2025_MINUS_07_MINUS_17 = 'google/veo-3-0-fast-generate-preview-2025-07-17'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_0_MINUS_GENERATE_MINUS_PREVIEW_MINUS_2025_MINUS_07_MINUS_17 = 'google/veo-3-0-generate-preview-2025-07-17'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_1_MINUS_FAST_MINUS_PREVIEW_MINUS_2025_MINUS_10_MINUS_15 = 'google/veo-3-1-fast-preview-2025-10-15'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_1_MINUS_PREVIEW_MINUS_2025_MINUS_10_MINUS_15 = 'google/veo-3-1-preview-2025-10-15'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_2025_MINUS_09_MINUS_09 = 'google/veo-3-2025-09-09'
    GOOGLE_SLASH_VEO_MINUS_3_MINUS_FAST_MINUS_2025_MINUS_09_MINUS_09 = 'google/veo-3-fast-2025-09-09'
    GOOGLE_SLASH_VEO_MINUS_4 = 'google/veo-4'
    IBM_SLASH_GRANITE_MINUS_20B_MINUS_CODE_MINUS_INSTRUCT_MINUS_8K = 'ibm/granite-20b-code-instruct-8k'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_0_MINUS_1B_MINUS_A400M_MINUS_INSTRUCT = 'ibm/granite-3-0-1b-a400m-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_0_MINUS_2B_MINUS_INSTRUCT = 'ibm/granite-3-0-2b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_0_MINUS_3B_MINUS_A800M_MINUS_INSTRUCT = 'ibm/granite-3-0-3b-a800m-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_0_MINUS_8B_MINUS_INSTRUCT = 'ibm/granite-3-0-8b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_1_MINUS_1B_MINUS_A400M_MINUS_INSTRUCT = 'ibm/granite-3-1-1b-a400m-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_1_MINUS_2B_MINUS_INSTRUCT = 'ibm/granite-3-1-2b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_1_MINUS_3B_MINUS_A800M_MINUS_INSTRUCT = 'ibm/granite-3-1-3b-a800m-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_1_MINUS_8B_MINUS_INSTRUCT = 'ibm/granite-3-1-8b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_2_MINUS_2B_MINUS_INSTRUCT = 'ibm/granite-3-2-2b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_2_MINUS_8B_MINUS_INSTRUCT = 'ibm/granite-3-2-8b-instruct'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_2_MINUS_8B_MINUS_INSTRUCT_MINUS_PREVIEW = 'ibm/granite-3-2-8b-instruct-preview'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_3_MINUS_2B_MINUS_INSTRUCT_MINUS_2025_MINUS_04_MINUS_16 = 'ibm/granite-3-3-2b-instruct-2025-04-16'
    IBM_SLASH_GRANITE_MINUS_3_MINUS_3_MINUS_8B_MINUS_INSTRUCT_MINUS_2025_MINUS_04_MINUS_16 = 'ibm/granite-3-3-8b-instruct-2025-04-16'
    IBM_SLASH_GRANITE_MINUS_34B_MINUS_CODE_MINUS_INSTRUCT_MINUS_8B = 'ibm/granite-34b-code-instruct-8b'
    IBM_SLASH_GRANITE_MINUS_3B_MINUS_CODE_MINUS_INSTRUCT_MINUS_128K = 'ibm/granite-3b-code-instruct-128k'
    IBM_SLASH_GRANITE_MINUS_3B_MINUS_CODE_MINUS_INSTRUCT_MINUS_2K = 'ibm/granite-3b-code-instruct-2k'
    IBM_SLASH_GRANITE_MINUS_4_MINUS_0_MINUS_MICRO_MINUS_2025_MINUS_10_MINUS_02 = 'ibm/granite-4-0-micro-2025-10-02'
    IBM_SLASH_GRANITE_MINUS_4_MINUS_0_MINUS_SMALL_MINUS_2025_MINUS_10_MINUS_02 = 'ibm/granite-4-0-small-2025-10-02'
    IBM_SLASH_GRANITE_MINUS_4_MINUS_0_MINUS_TINY_MINUS_2025_MINUS_10_MINUS_02 = 'ibm/granite-4-0-tiny-2025-10-02'
    IBM_SLASH_GRANITE_MINUS_4_MINUS_0_MINUS_TINY_MINUS_PREVIEW_MINUS_2025_MINUS_05_MINUS_02 = 'ibm/granite-4-0-tiny-preview-2025-05-02'
    IBM_SLASH_GRANITE_MINUS_8B_MINUS_CODE_MINUS_INSTRUCT_MINUS_128K = 'ibm/granite-8b-code-instruct-128k'
    IBM_SLASH_GRANITE_MINUS_8B_MINUS_CODE_MINUS_INSTRUCT_MINUS_4K = 'ibm/granite-8b-code-instruct-4k'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_107M_MINUS_MULTILINGUAL = 'ibm/granite-embedding-107m-multilingual'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_125M_MINUS_ENGLISH = 'ibm/granite-embedding-125m-english'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_278M_MINUS_MULTILINGUAL = 'ibm/granite-embedding-278m-multilingual'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_30M_MINUS_ENGLISH = 'ibm/granite-embedding-30m-english'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_ENGLISH_MINUS_R2 = 'ibm/granite-embedding-english-r2'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_RERANKER_MINUS_ENGLISH_MINUS_R2 = 'ibm/granite-embedding-reranker-english-r2'
    IBM_SLASH_GRANITE_MINUS_EMBEDDING_MINUS_SMALL_MINUS_ENGLISH_MINUS_R2 = 'ibm/granite-embedding-small-english-r2'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_0_MINUS_2B = 'ibm/granite-guardian-3-0-2b'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_0_MINUS_8B = 'ibm/granite-guardian-3-0-8b'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_1_MINUS_2B = 'ibm/granite-guardian-3-1-2b'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_1_MINUS_8B = 'ibm/granite-guardian-3-1-8b'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_2_MINUS_5B = 'ibm/granite-guardian-3-2-5b'
    IBM_SLASH_GRANITE_MINUS_GUARDIAN_MINUS_3_MINUS_3_MINUS_8B = 'ibm/granite-guardian-3-3-8b'
    IBM_SLASH_GRANITE_MINUS_SPEECH_MINUS_3_MINUS_2_MINUS_8B = 'ibm/granite-speech-3-2-8b'
    IBM_SLASH_GRANITE_MINUS_SPEECH_MINUS_3_MINUS_3_MINUS_2B = 'ibm/granite-speech-3-3-2b'
    IBM_SLASH_GRANITE_MINUS_SPEECH_MINUS_3_MINUS_3_MINUS_8B = 'ibm/granite-speech-3-3-8b'
    IBM_SLASH_GRANITE_MINUS_VISION_MINUS_3_MINUS_1_MINUS_2B_MINUS_PREVIEW = 'ibm/granite-vision-3-1-2b-preview'
    IBM_SLASH_GRANITE_MINUS_VISION_MINUS_3_MINUS_2_MINUS_2B = 'ibm/granite-vision-3-2-2b'
    IBM_SLASH_GRANITE_MINUS_VISION_MINUS_3_MINUS_3_MINUS_2B = 'ibm/granite-vision-3-3-2b'
    IBM_SLASH_GRANITE_MINUS_VISION_MINUS_3_MINUS_3_MINUS_2B_MINUS_EMBEDDING = 'ibm/granite-vision-3-3-2b-embedding'
    LG_SLASH_EXAONE_MINUS_3_MINUS_0_MINUS_2024_MINUS_08_MINUS_07 = 'lg/exaone-3-0-2024-08-07'
    LG_SLASH_EXAONE_MINUS_3_MINUS_5_MINUS_2_MINUS_4B_MINUS_2024_MINUS_12_MINUS_09 = 'lg/exaone-3-5-2-4b-2024-12-09'
    LG_SLASH_EXAONE_MINUS_3_MINUS_5_MINUS_32B_MINUS_2024_MINUS_12_MINUS_09 = 'lg/exaone-3-5-32b-2024-12-09'
    LG_SLASH_EXAONE_MINUS_3_MINUS_5_MINUS_7_MINUS_8B_MINUS_2024_MINUS_12_MINUS_09 = 'lg/exaone-3-5-7-8b-2024-12-09'
    LG_SLASH_EXAONE_MINUS_4_MINUS_0_MINUS_1_MINUS_2B_MINUS_2025_MINUS_07_MINUS_15 = 'lg/exaone-4-0-1-2b-2025-07-15'
    LG_SLASH_EXAONE_MINUS_4_MINUS_0_MINUS_32B_MINUS_2025_MINUS_07_MINUS_15 = 'lg/exaone-4-0-32b-2025-07-15'
    LG_SLASH_EXAONE_MINUS_DEEP_MINUS_2_MINUS_4B_MINUS_2025_MINUS_03_MINUS_18 = 'lg/exaone-deep-2-4b-2025-03-18'
    LG_SLASH_EXAONE_MINUS_DEEP_MINUS_32B_MINUS_2025_MINUS_03_MINUS_18 = 'lg/exaone-deep-32b-2025-03-18'
    LG_SLASH_EXAONE_MINUS_DEEP_MINUS_7_MINUS_8B_MINUS_2025_MINUS_03_MINUS_18 = 'lg/exaone-deep-7-8b-2025-03-18'
    META_SLASH_LLAMA_MINUS_2_MINUS_13B_MINUS_CHAT_MINUS_2023_MINUS_06_MINUS_20 = 'meta/llama-2-13b-chat-2023-06-20'
    META_SLASH_LLAMA_MINUS_2_MINUS_70B_MINUS_CHAT_MINUS_2023_MINUS_06_MINUS_20 = 'meta/llama-2-70b-chat-2023-06-20'
    META_SLASH_LLAMA_MINUS_2_MINUS_7B_MINUS_CHAT = 'meta/llama-2-7b-chat'
    META_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_405B_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_23 = 'meta/llama-3-1-405b-instruct-2024-07-23'
    META_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_70B_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_23 = 'meta/llama-3-1-70b-instruct-2024-07-23'
    META_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_8B_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_23 = 'meta/llama-3-1-8b-instruct-2024-07-23'
    META_SLASH_LLAMA_MINUS_3_MINUS_2_MINUS_11B_MINUS_VISION_MINUS_INSTRUCT = 'meta/llama-3-2-11b-vision-instruct'
    META_SLASH_LLAMA_MINUS_3_MINUS_2_MINUS_1B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_25 = 'meta/llama-3-2-1b-instruct-2024-09-25'
    META_SLASH_LLAMA_MINUS_3_MINUS_2_MINUS_3B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_25 = 'meta/llama-3-2-3b-instruct-2024-09-25'
    META_SLASH_LLAMA_MINUS_3_MINUS_2_MINUS_90B_MINUS_VISION_MINUS_INSTRUCT = 'meta/llama-3-2-90b-vision-instruct'
    META_SLASH_LLAMA_MINUS_3_MINUS_3_MINUS_70B_MINUS_INSTRUCT_MINUS_2024_MINUS_12_MINUS_06 = 'meta/llama-3-3-70b-instruct-2024-12-06'
    META_SLASH_LLAMA_MINUS_3_MINUS_70B_MINUS_INSTRUCT_MINUS_2024_MINUS_04_MINUS_18 = 'meta/llama-3-70b-instruct-2024-04-18'
    META_SLASH_LLAMA_MINUS_3_MINUS_8B_MINUS_INSTRUCT_MINUS_2024_MINUS_04_MINUS_18 = 'meta/llama-3-8b-instruct-2024-04-18'
    META_SLASH_LLAMA_MINUS_4_MINUS_MAVERICK_MINUS_2025_MINUS_04_MINUS_05 = 'meta/llama-4-maverick-2025-04-05'
    META_SLASH_LLAMA_MINUS_4_MINUS_SCOUT_MINUS_2025_MINUS_04_MINUS_05 = 'meta/llama-4-scout-2025-04-05'
    MICROSOFT_SLASH_PHI_MINUS_1 = 'microsoft/phi-1'
    MICROSOFT_SLASH_PHI_MINUS_1_MINUS_5 = 'microsoft/phi-1-5'
    MICROSOFT_SLASH_PHI_MINUS_2 = 'microsoft/phi-2'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_5_MINUS_MINI_MINUS_INSTRUCT_MINUS_2024_MINUS_08_MINUS_23 = 'microsoft/phi-3-5-mini-instruct-2024-08-23'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_5_MINUS_MOE_MINUS_INSTRUCT_MINUS_2024_MINUS_08_MINUS_23 = 'microsoft/phi-3-5-moe-instruct-2024-08-23'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_5_MINUS_VISION_MINUS_INSTRUCT_MINUS_2024_MINUS_08_MINUS_23 = 'microsoft/phi-3-5-vision-instruct-2024-08-23'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_MEDIUM_MINUS_128K_MINUS_INSTRUCT = 'microsoft/phi-3-medium-128k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_MEDIUM_MINUS_4K_MINUS_INSTRUCT = 'microsoft/phi-3-medium-4k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_MINI_MINUS_128K_MINUS_INSTRUCT = 'microsoft/phi-3-mini-128k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_SMALL_MINUS_128K_MINUS_INSTRUCT = 'microsoft/phi-3-small-128k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_SMALL_MINUS_8K_MINUS_INSTRUCT = 'microsoft/phi-3-small-8k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_3_MINUS_VISION_MINUS_128K_MINUS_INSTRUCT = 'microsoft/phi-3-vision-128k-instruct'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_2024_MINUS_12_MINUS_12 = 'microsoft/phi-4-2024-12-12'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_MINI_MINUS_2025_MINUS_02_MINUS_01 = 'microsoft/phi-4-mini-2025-02-01'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_MINI_MINUS_FLASH_MINUS_REASONING = 'microsoft/phi-4-mini-flash-reasoning'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_MINI_MINUS_REASONING_MINUS_2025_MINUS_04_MINUS_30 = 'microsoft/phi-4-mini-reasoning-2025-04-30'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_MULTIMODAL_MINUS_INSTRUCT_MINUS_2025_MINUS_02_MINUS_01 = 'microsoft/phi-4-multimodal-instruct-2025-02-01'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_REASONING_MINUS_2025_MINUS_04_MINUS_30 = 'microsoft/phi-4-reasoning-2025-04-30'
    MICROSOFT_SLASH_PHI_MINUS_4_MINUS_REASONING_MINUS_PLUS_MINUS_2025_MINUS_04_MINUS_30 = 'microsoft/phi-4-reasoning-plus-2025-04-30'
    MINIMAX_SLASH_HAILUO_MINUS_02 = 'minimax/hailuo-02'
    MINIMAX_SLASH_I2V_MINUS_01_MINUS_DIRECTOR = 'minimax/i2v-01-director'
    MINIMAX_SLASH_I2V_MINUS_01_MINUS_LIVE = 'minimax/i2v-01-live'
    MINIMAX_SLASH_IMAGE_MINUS_01 = 'minimax/image-01'
    MINIMAX_SLASH_MINIMAX_MINUS_M1_MINUS_2025_MINUS_06_MINUS_16 = 'minimax/minimax-m1-2025-06-16'
    MINIMAX_SLASH_MINIMAX_MINUS_M1_MINUS_40K = 'minimax/minimax-m1-40k'
    MINIMAX_SLASH_MINIMAX_MINUS_M2_MINUS_1 = 'minimax/minimax-m2-1'
    MINIMAX_SLASH_MINIMAX_MINUS_M2_MINUS_2025_MINUS_10_MINUS_27 = 'minimax/minimax-m2-2025-10-27'
    MINIMAX_SLASH_MINIMAX_MINUS_TEXT_MINUS_01 = 'minimax/minimax-text-01'
    MINIMAX_SLASH_MINIMAX_MINUS_VL_MINUS_01 = 'minimax/minimax-vl-01'
    MINIMAX_SLASH_MUSIC_MINUS_1_MINUS_5 = 'minimax/music-1-5'
    MINIMAX_SLASH_S2V_MINUS_01 = 'minimax/s2v-01'
    MINIMAX_SLASH_SPEECH_MINUS_01_MINUS_HD = 'minimax/speech-01-hd'
    MINIMAX_SLASH_SPEECH_MINUS_01_MINUS_TURBO = 'minimax/speech-01-turbo'
    MINIMAX_SLASH_SPEECH_MINUS_02_MINUS_HD = 'minimax/speech-02-hd'
    MINIMAX_SLASH_SPEECH_MINUS_02_MINUS_TURBO = 'minimax/speech-02-turbo'
    MINIMAX_SLASH_SPEECH_MINUS_2_MINUS_5_MINUS_HD_MINUS_PREVIEW = 'minimax/speech-2-5-hd-preview'
    MINIMAX_SLASH_SPEECH_MINUS_2_MINUS_5_MINUS_TURBO_MINUS_PREVIEW = 'minimax/speech-2-5-turbo-preview'
    MINIMAX_SLASH_T2V_MINUS_01_MINUS_DIRECTOR = 'minimax/t2v-01-director'
    MISTRAL_SLASH_CODESTRAL_MINUS_22B_MINUS_2024_MINUS_05_MINUS_29 = 'mistral/codestral-22b-2024-05-29'
    MISTRAL_SLASH_CODESTRAL_MINUS_2405 = 'mistral/codestral-2405'
    MISTRAL_SLASH_CODESTRAL_MINUS_2501 = 'mistral/codestral-2501'
    MISTRAL_SLASH_CODESTRAL_MINUS_2508 = 'mistral/codestral-2508'
    MISTRAL_SLASH_CODESTRAL_MINUS_EMBED = 'mistral/codestral-embed'
    MISTRAL_SLASH_DEVSTRAL_MINUS_MEDIUM_MINUS_1_MINUS_1_MINUS_2025_MINUS_07_MINUS_10 = 'mistral/devstral-medium-1-1-2025-07-10'
    MISTRAL_SLASH_DEVSTRAL_MINUS_SMALL = 'mistral/devstral-small'
    MISTRAL_SLASH_DEVSTRAL_MINUS_SMALL_MINUS_1_MINUS_1_MINUS_2025_MINUS_07_MINUS_10 = 'mistral/devstral-small-1-1-2025-07-10'
    MISTRAL_SLASH_MAGISTRAL_MINUS_MEDIUM_MINUS_2025_MINUS_06_MINUS_10 = 'mistral/magistral-medium-2025-06-10'
    MISTRAL_SLASH_MAGISTRAL_MINUS_MEDIUM_MINUS_2507 = 'mistral/magistral-medium-2507'
    MISTRAL_SLASH_MAGISTRAL_MINUS_MEDIUM_MINUS_2509 = 'mistral/magistral-medium-2509'
    MISTRAL_SLASH_MAGISTRAL_MINUS_SMALL_MINUS_2025_MINUS_06_MINUS_10 = 'mistral/magistral-small-2025-06-10'
    MISTRAL_SLASH_MAGISTRAL_MINUS_SMALL_MINUS_2507 = 'mistral/magistral-small-2507'
    MISTRAL_SLASH_MAGISTRAL_MINUS_SMALL_MINUS_2509 = 'mistral/magistral-small-2509'
    MISTRAL_SLASH_MAMBA_MINUS_CODESTRAL_MINUS_7B = 'mistral/mamba-codestral-7b'
    MISTRAL_SLASH_MATHSTRAL_MINUS_7B = 'mistral/mathstral-7b'
    MISTRAL_SLASH_MINISTRAL_MINUS_3B_MINUS_2410 = 'mistral/ministral-3b-2410'
    MISTRAL_SLASH_MINISTRAL_MINUS_8B_MINUS_2410 = 'mistral/ministral-8b-2410'
    MISTRAL_SLASH_MINISTRAL_MINUS_8B_MINUS_INSTRUCT_MINUS_2024_MINUS_10_MINUS_16 = 'mistral/ministral-8b-instruct-2024-10-16'
    MISTRAL_SLASH_MISTRAL_MINUS_7B = 'mistral/mistral-7b'
    MISTRAL_SLASH_MISTRAL_MINUS_EMBED = 'mistral/mistral-embed'
    MISTRAL_SLASH_MISTRAL_MINUS_LARGE_MINUS_2_MINUS_2024_MINUS_07_MINUS_24 = 'mistral/mistral-large-2-2024-07-24'
    MISTRAL_SLASH_MISTRAL_MINUS_LARGE_MINUS_2402 = 'mistral/mistral-large-2402'
    MISTRAL_SLASH_MISTRAL_MINUS_LARGE_MINUS_2407 = 'mistral/mistral-large-2407'
    MISTRAL_SLASH_MISTRAL_MINUS_LARGE_MINUS_2411 = 'mistral/mistral-large-2411'
    MISTRAL_SLASH_MISTRAL_MINUS_MEDIUM_MINUS_2312 = 'mistral/mistral-medium-2312'
    MISTRAL_SLASH_MISTRAL_MINUS_MEDIUM_MINUS_2505 = 'mistral/mistral-medium-2505'
    MISTRAL_SLASH_MISTRAL_MINUS_MEDIUM_MINUS_2508 = 'mistral/mistral-medium-2508'
    MISTRAL_SLASH_MISTRAL_MINUS_MODERATION_MINUS_2411 = 'mistral/mistral-moderation-2411'
    MISTRAL_SLASH_MISTRAL_MINUS_NEMO_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_18 = 'mistral/mistral-nemo-instruct-2024-07-18'
    MISTRAL_SLASH_MISTRAL_MINUS_OCR_MINUS_2503 = 'mistral/mistral-ocr-2503'
    MISTRAL_SLASH_MISTRAL_MINUS_OCR_MINUS_2505 = 'mistral/mistral-ocr-2505'
    MISTRAL_SLASH_MISTRAL_MINUS_SABA_MINUS_2502 = 'mistral/mistral-saba-2502'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2024_MINUS_09_MINUS_17 = 'mistral/mistral-small-2024-09-17'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2402 = 'mistral/mistral-small-2402'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2407 = 'mistral/mistral-small-2407'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2501 = 'mistral/mistral-small-2501'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2503 = 'mistral/mistral-small-2503'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_2506 = 'mistral/mistral-small-2506'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_3_MINUS_1_MINUS_24B_MINUS_BASE_MINUS_2025_MINUS_03_MINUS_17 = 'mistral/mistral-small-3-1-24b-base-2025-03-17'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_3_MINUS_1_MINUS_24B_MINUS_INSTRUCT_MINUS_2025_MINUS_03_MINUS_17 = 'mistral/mistral-small-3-1-24b-instruct-2025-03-17'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_3_MINUS_2_MINUS_2025_MINUS_06_MINUS_20 = 'mistral/mistral-small-3-2-2025-06-20'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_3_MINUS_24B_MINUS_BASE_MINUS_2025_MINUS_01_MINUS_30 = 'mistral/mistral-small-3-24b-base-2025-01-30'
    MISTRAL_SLASH_MISTRAL_MINUS_SMALL_MINUS_3_MINUS_24B_MINUS_INSTRUCT_MINUS_2025_MINUS_01_MINUS_30 = 'mistral/mistral-small-3-24b-instruct-2025-01-30'
    MISTRAL_SLASH_MIXTRAL_MINUS_8X22B = 'mistral/mixtral-8x22b'
    MISTRAL_SLASH_MIXTRAL_MINUS_8X7B = 'mistral/mixtral-8x7b'
    MISTRAL_SLASH_OPEN_MINUS_CODESTRAL_MINUS_MAMBA = 'mistral/open-codestral-mamba'
    MISTRAL_SLASH_OPEN_MINUS_MISTRAL_MINUS_7B = 'mistral/open-mistral-7b'
    MISTRAL_SLASH_OPEN_MINUS_MISTRAL_MINUS_NEMO = 'mistral/open-mistral-nemo'
    MISTRAL_SLASH_OPEN_MINUS_MIXTRAL_MINUS_8X22B = 'mistral/open-mixtral-8x22b'
    MISTRAL_SLASH_OPEN_MINUS_MIXTRAL_MINUS_8X7B = 'mistral/open-mixtral-8x7b'
    MISTRAL_SLASH_PIXTRAL_MINUS_12B_MINUS_BASE_MINUS_2024_MINUS_09_MINUS_17 = 'mistral/pixtral-12b-base-2024-09-17'
    MISTRAL_SLASH_PIXTRAL_MINUS_LARGE_MINUS_2024_MINUS_11_MINUS_18 = 'mistral/pixtral-large-2024-11-18'
    MISTRAL_SLASH_PIXTRAL_MINUS_LARGE_MINUS_2411 = 'mistral/pixtral-large-2411'
    MISTRAL_SLASH_VOXTRAL_MINUS_MINI_MINUS_2507 = 'mistral/voxtral-mini-2507'
    MISTRAL_SLASH_VOXTRAL_MINUS_SMALL_MINUS_2507 = 'mistral/voxtral-small-2507'
    MOONSHOTAI_SLASH_KIMI_MINUS_K1_MINUS_5_MINUS_2025_MINUS_01_MINUS_20 = 'moonshotai/kimi-k1-5-2025-01-20'
    MOONSHOTAI_SLASH_KIMI_MINUS_K2_MINUS_BASE_MINUS_2025_MINUS_07_MINUS_11 = 'moonshotai/kimi-k2-base-2025-07-11'
    MOONSHOTAI_SLASH_KIMI_MINUS_K2_MINUS_INSTRUCT_MINUS_0905 = 'moonshotai/kimi-k2-instruct-0905'
    MOONSHOTAI_SLASH_KIMI_MINUS_K2_MINUS_INSTRUCT_MINUS_2025_MINUS_07_MINUS_11 = 'moonshotai/kimi-k2-instruct-2025-07-11'
    MOONSHOTAI_SLASH_KIMI_MINUS_K2_MINUS_THINKING_MINUS_2025_MINUS_11_MINUS_06 = 'moonshotai/kimi-k2-thinking-2025-11-06'
    MOONSHOTAI_SLASH_KIMI_MINUS_VL_MINUS_A3B_MINUS_INSTRUCT = 'moonshotai/kimi-vl-a3b-instruct'
    MOONSHOTAI_SLASH_KIMI_MINUS_VL_MINUS_A3B_MINUS_THINKING = 'moonshotai/kimi-vl-a3b-thinking'
    MOONSHOTAI_SLASH_KIMI_MINUS_VL_MINUS_A3B_MINUS_THINKING_MINUS_2506 = 'moonshotai/kimi-vl-a3b-thinking-2506'
    NOUS_SLASH_HERMES_MINUS_2_MINUS_PRO_MINUS_LLAMA_MINUS_3_MINUS_70B = 'nous/hermes-2-pro-llama-3-70b'
    NOUS_SLASH_HERMES_MINUS_2_MINUS_PRO_MINUS_LLAMA_MINUS_3_MINUS_8B = 'nous/hermes-2-pro-llama-3-8b'
    NOUS_SLASH_HERMES_MINUS_2_MINUS_PRO_MINUS_MISTRAL_MINUS_7B = 'nous/hermes-2-pro-mistral-7b'
    NOUS_SLASH_HERMES_MINUS_2_MINUS_THETA_MINUS_LLAMA_MINUS_3_MINUS_70B = 'nous/hermes-2-theta-llama-3-70b'
    NOUS_SLASH_HERMES_MINUS_2_MINUS_THETA_MINUS_LLAMA_MINUS_3_MINUS_8B = 'nous/hermes-2-theta-llama-3-8b'
    NOUS_SLASH_HERMES_MINUS_3_MINUS_LLAMA_MINUS_3_MINUS_1_MINUS_405B = 'nous/hermes-3-llama-3-1-405b'
    NOUS_SLASH_HERMES_MINUS_3_MINUS_LLAMA_MINUS_3_MINUS_1_MINUS_70B = 'nous/hermes-3-llama-3-1-70b'
    NOUS_SLASH_HERMES_MINUS_3_MINUS_LLAMA_MINUS_3_MINUS_1_MINUS_8B = 'nous/hermes-3-llama-3-1-8b'
    NOUS_SLASH_HERMES_MINUS_3_MINUS_LLAMA_MINUS_3_MINUS_2_MINUS_3B = 'nous/hermes-3-llama-3-2-3b'
    NOUS_SLASH_HERMES_MINUS_4_MINUS_14B = 'nous/hermes-4-14b'
    NOUS_SLASH_HERMES_MINUS_4_MINUS_405B = 'nous/hermes-4-405b'
    NOUS_SLASH_HERMES_MINUS_4_MINUS_70B = 'nous/hermes-4-70b'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_NEMOTRON_MINUS_70B_MINUS_INSTRUCT_MINUS_2024_MINUS_10_MINUS_01 = 'nvidia/llama-3-1-nemotron-70b-instruct-2024-10-01'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_NEMOTRON_MINUS_NANO_MINUS_4B_MINUS_V1_MINUS_1 = 'nvidia/llama-3-1-nemotron-nano-4b-v1-1'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_NEMOTRON_MINUS_NANO_MINUS_8B_MINUS_V1_MINUS_2025_MINUS_03_MINUS_18 = 'nvidia/llama-3-1-nemotron-nano-8b-v1-2025-03-18'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_1_MINUS_NEMOTRON_MINUS_ULTRA_MINUS_253B_MINUS_V1_MINUS_2025_MINUS_04_MINUS_07 = 'nvidia/llama-3-1-nemotron-ultra-253b-v1-2025-04-07'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_3_MINUS_NEMOTRON_MINUS_SUPER_MINUS_49B_MINUS_V1_MINUS_2025_MINUS_03_MINUS_18 = 'nvidia/llama-3-3-nemotron-super-49b-v1-2025-03-18'
    NVIDIA_SLASH_LLAMA_MINUS_3_MINUS_3_MINUS_NEMOTRON_MINUS_SUPER_MINUS_49B_MINUS_V1_MINUS_5 = 'nvidia/llama-3-3-nemotron-super-49b-v1-5'
    NVIDIA_SLASH_NVIDIA_MINUS_NEMOTRON_MINUS_NANO_MINUS_12B_MINUS_V2 = 'nvidia/nvidia-nemotron-nano-12b-v2'
    NVIDIA_SLASH_NVIDIA_MINUS_NEMOTRON_MINUS_NANO_MINUS_9B_MINUS_V2 = 'nvidia/nvidia-nemotron-nano-9b-v2'
    NVIDIA_SLASH_OPENREASONING_MINUS_NEMOTRON_MINUS_1_MINUS_5B = 'nvidia/openreasoning-nemotron-1-5b'
    NVIDIA_SLASH_OPENREASONING_MINUS_NEMOTRON_MINUS_14B = 'nvidia/openreasoning-nemotron-14b'
    NVIDIA_SLASH_OPENREASONING_MINUS_NEMOTRON_MINUS_32B = 'nvidia/openreasoning-nemotron-32b'
    NVIDIA_SLASH_OPENREASONING_MINUS_NEMOTRON_MINUS_7B = 'nvidia/openreasoning-nemotron-7b'
    OPENAI_SLASH_ADA_MINUS_2020_MINUS_06_MINUS_11 = 'openai/ada-2020-06-11'
    OPENAI_SLASH_BABBAGE_MINUS_002 = 'openai/babbage-002'
    OPENAI_SLASH_BABBAGE_MINUS_2020_MINUS_06_MINUS_11 = 'openai/babbage-2020-06-11'
    OPENAI_SLASH_CHATGPT_MINUS_4O = 'openai/chatgpt-4o'
    OPENAI_SLASH_CODE_MINUS_CUSHMAN_MINUS_001 = 'openai/code-cushman-001'
    OPENAI_SLASH_CODE_MINUS_CUSHMAN_MINUS_002 = 'openai/code-cushman-002'
    OPENAI_SLASH_CODE_MINUS_DAVINCI_MINUS_001 = 'openai/code-davinci-001'
    OPENAI_SLASH_CODE_MINUS_DAVINCI_MINUS_002 = 'openai/code-davinci-002'
    OPENAI_SLASH_CODE_MINUS_DAVINCI_MINUS_EDIT_MINUS_001 = 'openai/code-davinci-edit-001'
    OPENAI_SLASH_CODE_MINUS_SEARCH_MINUS_ADA_MINUS_CODE_MINUS_001 = 'openai/code-search-ada-code-001'
    OPENAI_SLASH_CODE_MINUS_SEARCH_MINUS_BABBAGE_MINUS_CODE_MINUS_001 = 'openai/code-search-babbage-code-001'
    OPENAI_SLASH_CODE_MINUS_SEARCH_MINUS_BABBAGE_MINUS_TEXT_MINUS_001 = 'openai/code-search-babbage-text-001'
    OPENAI_SLASH_CODES_MINUS_SEARCH_MINUS_ADA_MINUS_TEXT_MINUS_001 = 'openai/codes-search-ada-text-001'
    OPENAI_SLASH_CODEX_MINUS_MINI_MINUS_2025_MINUS_05_MINUS_16 = 'openai/codex-mini-2025-05-16'
    OPENAI_SLASH_COMPUTER_MINUS_USE_MINUS_PREVIEW = 'openai/computer-use-preview'
    OPENAI_SLASH_CURIE_MINUS_2020_MINUS_06_MINUS_11 = 'openai/curie-2020-06-11'
    OPENAI_SLASH_DALL_MINUS_E_MINUS_2_MINUS_2022_MINUS_09_MINUS_28 = 'openai/dall-e-2-2022-09-28'
    OPENAI_SLASH_DALL_MINUS_E_MINUS_3_MINUS_2023_MINUS_10_MINUS_19 = 'openai/dall-e-3-2023-10-19'
    OPENAI_SLASH_DAVINCI_MINUS_002 = 'openai/davinci-002'
    OPENAI_SLASH_DAVINCI_MINUS_2020_MINUS_06_MINUS_11 = 'openai/davinci-2020-06-11'
    OPENAI_SLASH_GPT_MINUS_1_MINUS_2018_MINUS_06_MINUS_11 = 'openai/gpt-1-2018-06-11'
    OPENAI_SLASH_GPT_MINUS_2_MINUS_2019_MINUS_11_MINUS_05 = 'openai/gpt-2-2019-11-05'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_2020_MINUS_06_MINUS_11 = 'openai/gpt-3-2020-06-11'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_5_MINUS_TURBO_MINUS_0613 = 'openai/gpt-3-5-turbo-0613'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_5_MINUS_TURBO_MINUS_16K_MINUS_0613_MINUS_2023_MINUS_06_MINUS_13 = 'openai/gpt-3-5-turbo-16k-0613-2023-06-13'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_5_MINUS_TURBO_MINUS_2023_MINUS_03_MINUS_21 = 'openai/gpt-3-5-turbo-2023-03-21'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_5_MINUS_TURBO_MINUS_2023_MINUS_09_MINUS_28 = 'openai/gpt-3-5-turbo-2023-09-28'
    OPENAI_SLASH_GPT_MINUS_3_MINUS_5_MINUS_TURBO_MINUS_2023_MINUS_11_MINUS_06 = 'openai/gpt-3-5-turbo-2023-11-06'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_1_MINUS_2025_MINUS_04_MINUS_14 = 'openai/gpt-4-1-2025-04-14'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_1_MINUS_MINI_MINUS_2025_MINUS_04_MINUS_14 = 'openai/gpt-4-1-mini-2025-04-14'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_1_MINUS_NANO_MINUS_2025_MINUS_04_MINUS_14 = 'openai/gpt-4-1-nano-2025-04-14'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_2023_MINUS_03_MINUS_14 = 'openai/gpt-4-2023-03-14'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_2023_MINUS_06_MINUS_13 = 'openai/gpt-4-2023-06-13'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_32K = 'openai/gpt-4-32k'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_32K_MINUS_0314 = 'openai/gpt-4-32k-0314'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_32K_MINUS_0613 = 'openai/gpt-4-32k-0613'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_5_MINUS_2025_MINUS_02_MINUS_27 = 'openai/gpt-4-5-2025-02-27'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_TURBO_MINUS_2023_MINUS_03_MINUS_14 = 'openai/gpt-4-turbo-2023-03-14'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_TURBO_MINUS_2023_MINUS_11_MINUS_06 = 'openai/gpt-4-turbo-2023-11-06'
    OPENAI_SLASH_GPT_MINUS_4_MINUS_TURBO_MINUS_2024_MINUS_01_MINUS_25 = 'openai/gpt-4-turbo-2024-01-25'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_2024_MINUS_05_MINUS_13 = 'openai/gpt-4o-2024-05-13'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_2024_MINUS_08_MINUS_06 = 'openai/gpt-4o-2024-08-06'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_2024_MINUS_11_MINUS_20 = 'openai/gpt-4o-2024-11-20'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_AUDIO_MINUS_2024_MINUS_10_MINUS_01 = 'openai/gpt-4o-audio-2024-10-01'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_AUDIO_MINUS_2024_MINUS_12_MINUS_17 = 'openai/gpt-4o-audio-2024-12-17'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_AUDIO_MINUS_2025_MINUS_06_MINUS_03 = 'openai/gpt-4o-audio-2025-06-03'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_2024_MINUS_07_MINUS_18 = 'openai/gpt-4o-mini-2024-07-18'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_AUDIO_MINUS_PREVIEW = 'openai/gpt-4o-mini-audio-preview'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_REALTIME_MINUS_PREVIEW = 'openai/gpt-4o-mini-realtime-preview'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_SEARCH_MINUS_PREVIEW = 'openai/gpt-4o-mini-search-preview'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_TRANSCRIBE = 'openai/gpt-4o-mini-transcribe'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_MINI_MINUS_TTS = 'openai/gpt-4o-mini-tts'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_REALTIME_MINUS_PREVIEW_MINUS_2024_MINUS_10_MINUS_01 = 'openai/gpt-4o-realtime-preview-2024-10-01'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_REALTIME_MINUS_PREVIEW_MINUS_2024_MINUS_12_MINUS_17 = 'openai/gpt-4o-realtime-preview-2024-12-17'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_REALTIME_MINUS_PREVIEW_MINUS_2025_MINUS_06_MINUS_03 = 'openai/gpt-4o-realtime-preview-2025-06-03'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_SEARCH_MINUS_PREVIEW = 'openai/gpt-4o-search-preview'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_TRANSCRIBE = 'openai/gpt-4o-transcribe'
    OPENAI_SLASH_GPT_MINUS_4O_MINUS_TRANSCRIBE_MINUS_DIARIZE_MINUS_2025_MINUS_10_MINUS_15 = 'openai/gpt-4o-transcribe-diarize-2025-10-15'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_2025_MINUS_11_MINUS_12 = 'openai/gpt-5-1-2025-11-12'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_CHAT_MINUS_2025_MINUS_11_MINUS_13 = 'openai/gpt-5-1-chat-2025-11-13'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_CODEX_MINUS_2025_MINUS_11_MINUS_13 = 'openai/gpt-5-1-codex-2025-11-13'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_CODEX_MINUS_MAX_MINUS_2025_MINUS_11_MINUS_19 = 'openai/gpt-5-1-codex-max-2025-11-19'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_CODEX_MINUS_MINI_MINUS_2025_MINUS_11_MINUS_13 = 'openai/gpt-5-1-codex-mini-2025-11-13'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_1_MINUS_PRO = 'openai/gpt-5-1-pro'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_2025_MINUS_08_MINUS_07 = 'openai/gpt-5-2025-08-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_CHAT_MINUS_2025_MINUS_08_MINUS_07 = 'openai/gpt-5-chat-2025-08-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_CODEX_MINUS_2025_MINUS_09_MINUS_15 = 'openai/gpt-5-codex-2025-09-15'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_CODEX_MINUS_MINI_MINUS_2025_MINUS_11_MINUS_07 = 'openai/gpt-5-codex-mini-2025-11-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_MINI_MINUS_2025_MINUS_08_MINUS_07 = 'openai/gpt-5-mini-2025-08-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_NANO_MINUS_2025_MINUS_08_MINUS_07 = 'openai/gpt-5-nano-2025-08-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_PRO_MINUS_2025_MINUS_08_MINUS_07 = 'openai/gpt-5-pro-2025-08-07'
    OPENAI_SLASH_GPT_MINUS_5_MINUS_SEARCH_MINUS_API_MINUS_2025_MINUS_10_MINUS_14 = 'openai/gpt-5-search-api-2025-10-14'
    OPENAI_SLASH_GPT_MINUS_6 = 'openai/gpt-6'
    OPENAI_SLASH_GPT_MINUS_6_MINUS_MINI = 'openai/gpt-6-mini'
    OPENAI_SLASH_GPT_MINUS_6_MINUS_NANO = 'openai/gpt-6-nano'
    OPENAI_SLASH_GPT_MINUS_6_MINUS_PRO = 'openai/gpt-6-pro'
    OPENAI_SLASH_GPT_MINUS_AUDIO = 'openai/gpt-audio'
    OPENAI_SLASH_GPT_MINUS_AUDIO_MINUS_MINI_MINUS_2025_MINUS_10_MINUS_06 = 'openai/gpt-audio-mini-2025-10-06'
    OPENAI_SLASH_GPT_MINUS_IMAGE_MINUS_1 = 'openai/gpt-image-1'
    OPENAI_SLASH_GPT_MINUS_IMAGE_MINUS_1_MINUS_MINI_MINUS_2025_MINUS_10_MINUS_06 = 'openai/gpt-image-1-mini-2025-10-06'
    OPENAI_SLASH_GPT_MINUS_OSS_MINUS_120B_MINUS_2025_MINUS_08_MINUS_05 = 'openai/gpt-oss-120b-2025-08-05'
    OPENAI_SLASH_GPT_MINUS_OSS_MINUS_20B_MINUS_2025_MINUS_08_MINUS_05 = 'openai/gpt-oss-20b-2025-08-05'
    OPENAI_SLASH_GPT_MINUS_OSS_MINUS_SAFEGUARD_MINUS_120B_MINUS_2025_MINUS_10_MINUS_29 = 'openai/gpt-oss-safeguard-120b-2025-10-29'
    OPENAI_SLASH_GPT_MINUS_OSS_MINUS_SAFEGUARD_MINUS_20B_MINUS_2025_MINUS_10_MINUS_29 = 'openai/gpt-oss-safeguard-20b-2025-10-29'
    OPENAI_SLASH_GPT_MINUS_REALTIME = 'openai/gpt-realtime'
    OPENAI_SLASH_GPT_MINUS_REALTIME_MINUS_MINI_MINUS_2025_MINUS_10_MINUS_06 = 'openai/gpt-realtime-mini-2025-10-06'
    OPENAI_SLASH_O1_MINUS_2024_MINUS_12_MINUS_17 = 'openai/o1-2024-12-17'
    OPENAI_SLASH_O1_MINUS_MINI_MINUS_2024_MINUS_09_MINUS_12 = 'openai/o1-mini-2024-09-12'
    OPENAI_SLASH_O1_MINUS_PREVIEW_MINUS_2024_MINUS_09_MINUS_12 = 'openai/o1-preview-2024-09-12'
    OPENAI_SLASH_O1_MINUS_PRO_MINUS_2025_MINUS_03_MINUS_19 = 'openai/o1-pro-2025-03-19'
    OPENAI_SLASH_O3_MINUS_2025_MINUS_04_MINUS_16 = 'openai/o3-2025-04-16'
    OPENAI_SLASH_O3_MINUS_DEEP_MINUS_RESEARCH_MINUS_2025_MINUS_06_MINUS_26 = 'openai/o3-deep-research-2025-06-26'
    OPENAI_SLASH_O3_MINUS_MINI_MINUS_2025_MINUS_01_MINUS_30 = 'openai/o3-mini-2025-01-30'
    OPENAI_SLASH_O3_MINUS_PREVIEW = 'openai/o3-preview'
    OPENAI_SLASH_O3_MINUS_PRO_MINUS_2025_MINUS_06_MINUS_10 = 'openai/o3-pro-2025-06-10'
    OPENAI_SLASH_O4_MINUS_MINI_MINUS_2025_MINUS_04_MINUS_16 = 'openai/o4-mini-2025-04-16'
    OPENAI_SLASH_O4_MINUS_MINI_MINUS_DEEP_MINUS_RESEARCH_MINUS_2025_MINUS_06_MINUS_26 = 'openai/o4-mini-deep-research-2025-06-26'
    OPENAI_SLASH_OMNI_MINUS_MODERATION_MINUS_2024_MINUS_09_MINUS_26 = 'openai/omni-moderation-2024-09-26'
    OPENAI_SLASH_SORA_MINUS_1_MINUS_2024_MINUS_12_MINUS_09 = 'openai/sora-1-2024-12-09'
    OPENAI_SLASH_SORA_MINUS_2_MINUS_2025_MINUS_09_MINUS_30 = 'openai/sora-2-2025-09-30'
    OPENAI_SLASH_SORA_MINUS_2_MINUS_PRO_MINUS_2025_MINUS_10_MINUS_03 = 'openai/sora-2-pro-2025-10-03'
    OPENAI_SLASH_TEXT_MINUS_ADA_MINUS_001 = 'openai/text-ada-001'
    OPENAI_SLASH_TEXT_MINUS_BABBAGE_MINUS_001 = 'openai/text-babbage-001'
    OPENAI_SLASH_TEXT_MINUS_CURIE_MINUS_001 = 'openai/text-curie-001'
    OPENAI_SLASH_TEXT_MINUS_DAVINCI_MINUS_001 = 'openai/text-davinci-001'
    OPENAI_SLASH_TEXT_MINUS_DAVINCI_MINUS_002 = 'openai/text-davinci-002'
    OPENAI_SLASH_TEXT_MINUS_DAVINCI_MINUS_003 = 'openai/text-davinci-003'
    OPENAI_SLASH_TEXT_MINUS_DAVINCI_MINUS_EDIT_MINUS_001 = 'openai/text-davinci-edit-001'
    OPENAI_SLASH_TEXT_MINUS_EMBEDDING_MINUS_3_MINUS_LARGE = 'openai/text-embedding-3-large'
    OPENAI_SLASH_TEXT_MINUS_EMBEDDING_MINUS_3_MINUS_SMALL = 'openai/text-embedding-3-small'
    OPENAI_SLASH_TEXT_MINUS_EMBEDDING_MINUS_ADA_MINUS_002 = 'openai/text-embedding-ada-002'
    OPENAI_SLASH_TEXT_MINUS_MODERATION_MINUS_007 = 'openai/text-moderation-007'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_ADA_MINUS_DOC_MINUS_001 = 'openai/text-search-ada-doc-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_ADA_MINUS_QUERY_MINUS_001 = 'openai/text-search-ada-query-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_BABBAGE_MINUS_DOC_MINUS_001 = 'openai/text-search-babbage-doc-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_BABBAGE_MINUS_QUERY_MINUS_001 = 'openai/text-search-babbage-query-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_CURIE_MINUS_DOC_MINUS_001 = 'openai/text-search-curie-doc-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_CURIE_MINUS_QUERY_MINUS_001 = 'openai/text-search-curie-query-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_DAVINCI_MINUS_DOC_MINUS_001 = 'openai/text-search-davinci-doc-001'
    OPENAI_SLASH_TEXT_MINUS_SEARCH_MINUS_DAVINCI_MINUS_QUERY_MINUS_001 = 'openai/text-search-davinci-query-001'
    OPENAI_SLASH_TEXT_MINUS_SIMILARITY_MINUS_ADA_MINUS_001 = 'openai/text-similarity-ada-001'
    OPENAI_SLASH_TEXT_MINUS_SIMILARITY_MINUS_BABBAGE_MINUS_001 = 'openai/text-similarity-babbage-001'
    OPENAI_SLASH_TEXT_MINUS_SIMILARITY_MINUS_CURIE_MINUS_001 = 'openai/text-similarity-curie-001'
    OPENAI_SLASH_TEXT_MINUS_SIMILARITY_MINUS_DAVINCI_MINUS_001 = 'openai/text-similarity-davinci-001'
    OPENAI_SLASH_TTS_MINUS_1 = 'openai/tts-1'
    OPENAI_SLASH_TTS_MINUS_1_MINUS_HD = 'openai/tts-1-hd'
    OPENAI_SLASH_WHISPER_MINUS_1 = 'openai/whisper-1'
    QWEN_SLASH_QVQ_MINUS_72B_MINUS_PREVIEW_MINUS_2024_MINUS_12_MINUS_25 = 'qwen/qvq-72b-preview-2024-12-25'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_14B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-14b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_32B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-32b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_72B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-72b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_7B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-7b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_CODER_MINUS_32B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-coder-32b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_CODER_MINUS_7B_MINUS_INSTRUCT_MINUS_2024_MINUS_09_MINUS_19 = 'qwen/qwen2-5-coder-7b-instruct-2024-09-19'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_OMNI_MINUS_7B_MINUS_2025_MINUS_03_MINUS_27 = 'qwen/qwen2-5-omni-7b-2025-03-27'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_VL_MINUS_32B_MINUS_INSTRUCT_MINUS_2025_MINUS_02_MINUS_28 = 'qwen/qwen2-5-vl-32b-instruct-2025-02-28'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_VL_MINUS_72B_MINUS_INSTRUCT_MINUS_2025_MINUS_01_MINUS_26 = 'qwen/qwen2-5-vl-72b-instruct-2025-01-26'
    QWEN_SLASH_QWEN2_MINUS_5_MINUS_VL_MINUS_7B_MINUS_INSTRUCT_MINUS_2025_MINUS_01_MINUS_26 = 'qwen/qwen2-5-vl-7b-instruct-2025-01-26'
    QWEN_SLASH_QWEN2_MINUS_72B_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_23 = 'qwen/qwen2-72b-instruct-2024-07-23'
    QWEN_SLASH_QWEN2_MINUS_7B_MINUS_INSTRUCT_MINUS_2024_MINUS_07_MINUS_23 = 'qwen/qwen2-7b-instruct-2024-07-23'
    QWEN_SLASH_QWEN2_MINUS_VL_MINUS_72B_MINUS_INSTRUCT_MINUS_2024_MINUS_08_MINUS_29 = 'qwen/qwen2-vl-72b-instruct-2024-08-29'
    QWEN_SLASH_QWEN3_MINUS_235B_MINUS_A22B_MINUS_2025_MINUS_04_MINUS_29 = 'qwen/qwen3-235b-a22b-2025-04-29'
    QWEN_SLASH_QWEN3_MINUS_235B_MINUS_A22B_MINUS_THINKING_MINUS_2507_MINUS_2025_MINUS_07_MINUS_25 = 'qwen/qwen3-235b-a22b-thinking-2507-2025-07-25'
    QWEN_SLASH_QWEN3_MINUS_30B_MINUS_A3B_MINUS_2025_MINUS_04_MINUS_29 = 'qwen/qwen3-30b-a3b-2025-04-29'
    QWEN_SLASH_QWEN3_MINUS_32B_MINUS_2025_MINUS_04_MINUS_29 = 'qwen/qwen3-32b-2025-04-29'
    QWEN_SLASH_QWEN3_MINUS_A235_MINUS_A22B_MINUS_INSTRUCT_MINUS_2507_MINUS_2025_MINUS_07_MINUS_21 = 'qwen/qwen3-a235-a22b-instruct-2507-2025-07-21'
    QWEN_SLASH_QWEN3_MINUS_CODER_MINUS_480B_MINUS_A35B_MINUS_INSTRUCT_MINUS_2025_MINUS_07_MINUS_22 = 'qwen/qwen3-coder-480b-a35b-instruct-2025-07-22'
    QWEN_SLASH_QWQ_MINUS_32B_MINUS_2025_MINUS_03_MINUS_05 = 'qwen/qwq-32b-2025-03-05'
    QWEN_SLASH_QWQ_MINUS_32B_MINUS_PREVIEW_MINUS_2024_MINUS_11_MINUS_28 = 'qwen/qwq-32b-preview-2024-11-28'
    SUNO_SLASH_SUNO_MINUS_V3_MINUS_5 = 'suno/suno-v3-5'
    SUNO_SLASH_SUNO_MINUS_V4 = 'suno/suno-v4'
    SUNO_SLASH_SUNO_MINUS_V4_MINUS_5 = 'suno/suno-v4-5'
    SUNO_SLASH_SUNO_MINUS_V4_MINUS_5_PLUS = 'suno/suno-v4-5+'
    SUNO_SLASH_SUNO_MINUS_V5 = 'suno/suno-v5'
    X_MINUS_AI_SLASH_GROK_MINUS_0 = 'x-ai/grok-0'
    X_MINUS_AI_SLASH_GROK_MINUS_1 = 'x-ai/grok-1'
    X_MINUS_AI_SLASH_GROK_MINUS_1_MINUS_5_MINUS_2024_MINUS_03_MINUS_28 = 'x-ai/grok-1-5-2024-03-28'
    X_MINUS_AI_SLASH_GROK_MINUS_1_MINUS_5V_MINUS_2024_MINUS_04_MINUS_12 = 'x-ai/grok-1-5v-2024-04-12'
    X_MINUS_AI_SLASH_GROK_MINUS_2_MINUS_2024_MINUS_08_MINUS_13 = 'x-ai/grok-2-2024-08-13'
    X_MINUS_AI_SLASH_GROK_MINUS_2_MINUS_IMAGE_MINUS_1212 = 'x-ai/grok-2-image-1212'
    X_MINUS_AI_SLASH_GROK_MINUS_2_MINUS_MINI_MINUS_2024_MINUS_08_MINUS_13 = 'x-ai/grok-2-mini-2024-08-13'
    X_MINUS_AI_SLASH_GROK_MINUS_2_MINUS_VISION_MINUS_1212 = 'x-ai/grok-2-vision-1212'
    X_MINUS_AI_SLASH_GROK_MINUS_3_MINUS_2025_MINUS_04_MINUS_18 = 'x-ai/grok-3-2025-04-18'
    X_MINUS_AI_SLASH_GROK_MINUS_3_MINUS_BETA_MINUS_2025_MINUS_02_MINUS_19 = 'x-ai/grok-3-beta-2025-02-19'
    X_MINUS_AI_SLASH_GROK_MINUS_3_MINUS_MINI_MINUS_2025_MINUS_04_MINUS_18 = 'x-ai/grok-3-mini-2025-04-18'
    X_MINUS_AI_SLASH_GROK_MINUS_3_MINUS_MINI_MINUS_BETA_MINUS_2025_MINUS_02_MINUS_19 = 'x-ai/grok-3-mini-beta-2025-02-19'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_1_MINUS_NON_MINUS_THINKING_MINUS_2025_MINUS_11_MINUS_17 = 'x-ai/grok-4-1-non-thinking-2025-11-17'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_1_MINUS_THINKING_MINUS_2025_MINUS_11_MINUS_17 = 'x-ai/grok-4-1-thinking-2025-11-17'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_2025_MINUS_07_MINUS_10 = 'x-ai/grok-4-2025-07-10'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_FAST_MINUS_NON_MINUS_REASONING_MINUS_2025_MINUS_09_MINUS_20 = 'x-ai/grok-4-fast-non-reasoning-2025-09-20'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_FAST_MINUS_REASONING_MINUS_2025_MINUS_09_MINUS_20 = 'x-ai/grok-4-fast-reasoning-2025-09-20'
    X_MINUS_AI_SLASH_GROK_MINUS_4_MINUS_HEAVY_MINUS_2025_MINUS_07_MINUS_10 = 'x-ai/grok-4-heavy-2025-07-10'
    X_MINUS_AI_SLASH_GROK_MINUS_CODE_MINUS_FAST_MINUS_1_MINUS_2025_MINUS_08_MINUS_28 = 'x-ai/grok-code-fast-1-2025-08-28'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_1V_MINUS_9B = 'z-ai/glm-4-1v-9b'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_1V_MINUS_THINKING_MINUS_9B = 'z-ai/glm-4-1v-thinking-9b'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_32B_MINUS_0414 = 'z-ai/glm-4-32b-0414'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_5 = 'z-ai/glm-4-5'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_5_MINUS_AIR = 'z-ai/glm-4-5-air'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_5V = 'z-ai/glm-4-5v'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_6_MINUS_2025_MINUS_09_MINUS_30 = 'z-ai/glm-4-6-2025-09-30'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_9B = 'z-ai/glm-4-9b'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_9B_MINUS_0414 = 'z-ai/glm-4-9b-0414'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_9B_MINUS_CHAT = 'z-ai/glm-4-9b-chat'
    Z_MINUS_AI_SLASH_GLM_MINUS_4_MINUS_9B_MINUS_CHAT_MINUS_1M = 'z-ai/glm-4-9b-chat-1m'
    Z_MINUS_AI_SLASH_GLM_MINUS_4V_MINUS_9B = 'z-ai/glm-4v-9b'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ModelId from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from ai_stats_generated.models.gateway_model_provider import GatewayModelProvider
from ai_stats_generated.models.organisation_id import OrganisationId
from typing import Optional, Set
from typing_extensions import Self

class GatewayModel(BaseModel):
    """
    GatewayModel
    """ # noqa: E501
    model_id: StrictStr = Field(description="Canonical model identifier.")
    name: Optional[StrictStr] = Field(description="Human readable model name.")
    release_date: Optional[date] = Field(description="Earliest known public release date.")
    announcement_date: Optional[date] = Field(description="Earliest known public announcement date if different from release.")
    status: Optional[StrictStr] = Field(description="Lifecycle status of the model (Rumoured, Announced, Available, Deprecated, Retired).")
    organisation: Optional[OrganisationId]
    aliases: List[StrictStr] = Field(description="Enabled aliases that resolve to this model.")
    endpoints: List[StrictStr] = Field(description="Gateway endpoints that currently route to this model.")
    providers: List[GatewayModelProvider] = Field(description="Provider mappings that can serve this model.")
    input_types: List[StrictStr] = Field(description="Input content types supported by the model itself.")
    output_types: List[StrictStr] = Field(description="Output content types supported by the model itself.")
    __properties: ClassVar[List[str]] = ["model_id", "name", "release_date", "announcement_date", "status", "organisation", "aliases", "endpoints", "providers", "input_types", "output_types"]

    @field_validator('endpoints')
    def endpoints_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['chat.completions', 'images.generations', 'audio.speech', 'audio.transcription', 'moderations', 'video.generation', 'embeddings', 'batch']):
                raise ValueError("each list item must be one of ('chat.completions', 'images.generations', 'audio.speech', 'audio.transcription', 'moderations', 'video.generation', 'embeddings', 'batch')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in providers (list)
        _items = []
        if self.providers:
            for _item_providers in self.providers:
                if _item_providers:
                    _items.append(_item_providers.to_dict())
            _dict['providers'] = _items
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if release_date (nullable) is None
        # and model_fields_set contains the field
        if self.release_date is None and "release_date" in self.model_fields_set:
            _dict['release_date'] = None

        # set to None if announcement_date (nullable) is None
        # and model_fields_set contains the field
        if self.announcement_date is None and "announcement_date" in self.model_fields_set:
            _dict['announcement_date'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if organisation (nullable) is None
        # and model_fields_set contains the field
        if self.organisation is None and "organisation" in self.model_fields_set:
            _dict['organisation'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "model_id": obj.get("model_id"),
            "name": obj.get("name"),
            "release_date": obj.get("release_date"),
            "announcement_date": obj.get("announcement_date"),
            "status": obj.get("status"),
            "organisation": obj.get("organisation"),
            "aliases": obj.get("aliases"),
            "endpoints": obj.get("endpoints"),
            "providers": [GatewayModelProvider.from_dict(_item) for _item in obj["providers"]] if obj.get("providers") is not None else None,
            "input_types": obj.get("input_types"),
            "output_types": obj.get("output_types")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0"

# Define package exports
__all__ = [
    "AnalyticsApi",
    "CompletionsApi",
    "GenerationsApi",
    "ImagesApi",
    "ModelsApi",
    "ModerationsApi",
    "VideoApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BenchmarkId",
    "ChatCompletionsRequest",
    "ChatCompletionsRequestReasoning",
    "ChatCompletionsRequestToolChoice",
    "ChatCompletionsResponse",
    "ChatMessage",
    "ChatMessageAssistant",
    "ChatMessageSystem",
    "ChatMessageTool",
    "ChatMessageUser",
    "GatewayChatChoice",
    "GatewayChatChoiceMessage",
    "GatewayError",
    "GatewayErrorMeta",
    "GatewayGenerationRecord",
    "GatewayHealthProvider",
    "GatewayHealthResponse",
    "GatewayHealthResponseOverall",
    "GatewayHealthResponseScope",
    "GatewayImageData",
    "GatewayMetadata",
    "GatewayModel",
    "GatewayModelProvider",
    "GatewayOrganisation",
    "GatewayResponseEnvelope",
    "GatewayUsage",
    "ImageGenerationRequest",
    "ImageGenerationResponse",
    "MessageContent",
    "MessageContentImageUrl",
    "MessageContentImageUrlImageUrl",
    "MessageContentInputAudio",
    "MessageContentInputAudioInputAudio",
    "MessageContentInputVideo",
    "MessageContentPart",
    "MessageContentText",
    "ModelId",
    "ModelListResponse",
    "ModelsGetIncludeEndpointsParameter",
    "ModelsGetOrganisationParameter",
    "ModelsGetProviderParameter",
    "ModerationInputContentItem",
    "ModerationInputImageUrlItem",
    "ModerationInputImageUrlItemImageUrl",
    "ModerationInputTextItem",
    "ModerationRequest",
    "ModerationRequestInput",
    "ModerationResponse",
    "ModerationResult",
    "OrganisationId",
    "ToolCall",
    "ToolCallFunction",
    "ToolCallPart",
    "VideoGenerationRequest",
    "VideoGenerationResponse",
]

# import apis into sdk package
from ai_stats_generated.api.analytics_api import AnalyticsApi as AnalyticsApi
from ai_stats_generated.api.completions_api import CompletionsApi as CompletionsApi
from ai_stats_generated.api.generations_api import GenerationsApi as GenerationsApi
from ai_stats_generated.api.images_api import ImagesApi as ImagesApi
from ai_stats_generated.api.models_api import ModelsApi as ModelsApi
from ai_stats_generated.api.moderations_api import ModerationsApi as ModerationsApi
from ai_stats_generated.api.video_api import VideoApi as VideoApi

# import ApiClient
from ai_stats_generated.api_response import ApiResponse as ApiResponse
from ai_stats_generated.api_client import ApiClient as ApiClient
from ai_stats_generated.configuration import Configuration as Configuration
from ai_stats_generated.exceptions import OpenApiException as OpenApiException
from ai_stats_generated.exceptions import ApiTypeError as ApiTypeError
from ai_stats_generated.exceptions import ApiValueError as ApiValueError
from ai_stats_generated.exceptions import ApiKeyError as ApiKeyError
from ai_stats_generated.exceptions import ApiAttributeError as ApiAttributeError
from ai_stats_generated.exceptions import ApiException as ApiException

# import models into sdk package
from ai_stats_generated.models.benchmark_id import BenchmarkId as BenchmarkId
from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest as ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning as ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice as ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse as ChatCompletionsResponse
from ai_stats_generated.models.chat_message import ChatMessage as ChatMessage
from ai_stats_generated.models.chat_message_assistant import ChatMessageAssistant as ChatMessageAssistant
from ai_stats_generated.models.chat_message_system import ChatMessageSystem as ChatMessageSystem
from ai_stats_generated.models.chat_message_tool import ChatMessageTool as ChatMessageTool
from ai_stats_generated.models.chat_message_user import ChatMessageUser as ChatMessageUser
from ai_stats_generated.models.gateway_chat_choice import GatewayChatChoice as GatewayChatChoice
from ai_stats_generated.models.gateway_chat_choice_message import GatewayChatChoiceMessage as GatewayChatChoiceMessage
from ai_stats_generated.models.gateway_error import GatewayError as GatewayError
from ai_stats_generated.models.gateway_error_meta import GatewayErrorMeta as GatewayErrorMeta
from ai_stats_generated.models.gateway_generation_record import GatewayGenerationRecord as GatewayGenerationRecord
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider as GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse as GatewayHealthResponse
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall as GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope as GatewayHealthResponseScope
from ai_stats_generated.models.gateway_image_data import GatewayImageData as GatewayImageData
from ai_stats_generated.models.gateway_metadata import GatewayMetadata as GatewayMetadata
from ai_stats_generated.models.gateway_model import GatewayModel as GatewayModel
from ai_stats_generated.models.gateway_model_provider import GatewayModelProvider as GatewayModelProvider
from ai_stats_generated.models.gateway_organisation import GatewayOrganisation as GatewayOrganisation
from ai_stats_generated.models.gateway_response_envelope import GatewayResponseEnvelope as GatewayResponseEnvelope
from ai_stats_generated.models.gateway_usage import GatewayUsage as GatewayUsage
from ai_stats_generated.models.image_generation_request import ImageGenerationRequest as ImageGenerationRequest
from ai_stats_generated.models.image_generation_response import ImageGenerationResponse as ImageGenerationResponse
from ai_stats_generated.models.message_content import MessageContent as MessageContent
from ai_stats_generated.models.message_content_image_url import MessageContentImageUrl as MessageContentImageUrl
from ai_stats_generated.models.message_content_image_url_image_url import MessageContentImageUrlImageUrl as MessageContentImageUrlImageUrl
from ai_stats_generated.models.message_content_input_audio import MessageContentInputAudio as MessageContentInputAudio
from ai_stats_generated.models.message_content_input_audio_input_audio import MessageContentInputAudioInputAudio as MessageContentInputAudioInputAudio
from ai_stats_generated.models.message_content_input_video import MessageContentInputVideo as MessageContentInputVideo
from ai_stats_generated.models.message_content_part import MessageContentPart as MessageContentPart
from ai_stats_generated.models.message_content_text import MessageContentText as MessageContentText
from ai_stats_generated.models.model_id import ModelId as ModelId
from ai_stats_generated.models.model_list_response import ModelListResponse as ModelListResponse
from ai_stats_generated.models.models_get_include_endpoints_parameter import ModelsGetIncludeEndpointsParameter as ModelsGetIncludeEndpointsParameter
from ai_stats_generated.models.models_get_organisation_parameter import ModelsGetOrganisationParameter as ModelsGetOrganisationParameter
from ai_stats_generated.models.models_get_provider_parameter import ModelsGetProviderParameter as ModelsGetProviderParameter
from ai_stats_generated.models.moderation_input_content_item import ModerationInputContentItem as ModerationInputContentItem
from ai_stats_generated.models.moderation_input_image_url_item import ModerationInputImageUrlItem as ModerationInputImageUrlItem
from ai_stats_generated.models.moderation_input_image_url_item_image_url import ModerationInputImageUrlItemImageUrl as ModerationInputImageUrlItemImageUrl
from ai_stats_generated.models.moderation_input_text_item import ModerationInputTextItem as ModerationInputTextItem
from ai_stats_generated.models.moderation_request import ModerationRequest as ModerationRequest
from ai_stats_generated.models.moderation_request_input import ModerationRequestInput as ModerationRequestInput
from ai_stats_generated.models.moderation_response import ModerationResponse as ModerationResponse
from ai_stats_generated.models.moderation_result import ModerationResult as ModerationResult
from ai_stats_generated.models.organisation_id import OrganisationId as OrganisationId
from ai_stats_generated.models.tool_call import ToolCall as ToolCall
from ai_stats_generated.models.tool_call_function import ToolCallFunction as ToolCallFunction
from ai_stats_generated.models.tool_call_part import ToolCallPart as ToolCallPart
from ai_stats_generated.models.video_generation_request import VideoGenerationRequest as VideoGenerationRequest
from ai_stats_generated.models.video_generation_response import VideoGenerationResponse as VideoGenerationResponse




# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse
from ai_stats_generated.models.model_id import ModelId

from ai_stats_generated.api_client import ApiClient, RequestSerialized
from ai_stats_generated.api_response import ApiResponse
from ai_stats_generated.rest import RESTResponseType


class AnalyticsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def health_get(
        self,
        provider: Annotated[Optional[StrictStr], Field(description="Filter to a specific provider name.")] = None,
        model: Annotated[Optional[ModelId], Field(description="Optional model id used to resolve candidate providers.")] = None,
        endpoint: Annotated[Optional[StrictStr], Field(description="Endpoint identifier paired with `model` when deriving providers.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GatewayHealthResponse:
        """Inspect provider health

        Returns the most recent latency, success rate, and breaker status for each configured provider.

        :param provider: Filter to a specific provider name.
        :type provider: str
        :param model: Optional model id used to resolve candidate providers.
        :type model: ModelId
        :param endpoint: Endpoint identifier paired with `model` when deriving providers.
        :type endpoint: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._health_get_serialize(
            provider=provider,
            model=model,
            endpoint=endpoint,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GatewayHealthResponse",
            '404': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def health_get_with_http_info(
        self,
        provider: Annotated[Optional[StrictStr], Field(description="Filter to a specific provider name.")] = None,
        model: Annotated[Optional[ModelId], Field(description="Optional model id used to resolve candidate providers.")] = None,
        endpoint: Annotated[Optional[StrictStr], Field(description="Endpoint identifier paired with `model` when deriving providers.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GatewayHealthResponse]:
        """Inspect provider health

        Returns the most recent latency, success rate, and breaker status for each configured provider.

        :param provider: Filter to a specific provider name.
        :type provider: str
        :param model: Optional model id used to resolve candidate providers.
        :type model: ModelId
        :param endpoint: Endpoint identifier paired with `model` when deriving providers.
        :type endpoint: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._health_get_serialize(
            provider=provider,
            model=model,
            endpoint=endpoint,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GatewayHealthResponse",
            '404': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def health_get_without_preload_content(
        self,
        provider: Annotated[Optional[StrictStr], Field(description="Filter to a specific provider name.")] = None,
        model: Annotated[Optional[ModelId], Field(description="Optional model id used to resolve candidate providers.")] = None,
        endpoint: Annotated[Optional[StrictStr], Field(description="Endpoint identifier paired with `model` when deriving providers.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Inspect provider health

        Returns the most recent latency, success rate, and breaker status for each configured provider.

        :param provider: Filter to a specific provider name.
        :type provider: str
        :param model: Optional model id used to resolve candidate providers.
        :type model: ModelId
        :param endpoint: Endpoint identifier paired with `model` when deriving providers.
        :type endpoint: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._health_get_serialize(
            provider=provider,
            model=model,
            endpoint=endpoint,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GatewayHealthResponse",
            '404': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _health_get_serialize(
        self,
        provider,
        model,
        endpoint,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if provider is not None:
            
            _query_params.append(('provider', provider))
            
        if model is not None:
            
            _query_params.append(('model', model.value))
            
        if endpoint is not None:
            
            _query_params.append(('endpoint', endpoint))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'GatewayAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/health',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class GatewayGenerationRecord(BaseModel):
    """
    GatewayGenerationRecord
    """ # noqa: E501
    request_id: StrictStr
    team_id: StrictStr
    app_id: Optional[StrictStr] = None
    app_title: Optional[StrictStr] = None
    referer: Optional[StrictStr] = None
    endpoint: StrictStr
    model_id: Optional[StrictStr] = None
    provider: Optional[StrictStr] = None
    native_response_id: Optional[StrictStr] = None
    stream: Optional[StrictBool] = None
    byok: Optional[StrictBool] = None
    status_code: Optional[StrictInt] = None
    success: StrictBool
    error_code: Optional[StrictStr] = None
    error_message: Optional[StrictStr] = None
    before: Optional[Dict[str, Any]] = None
    execute: Optional[Dict[str, Any]] = None
    latency_ms: Optional[Union[StrictFloat, StrictInt]] = None
    generation_ms: Optional[Union[StrictFloat, StrictInt]] = None
    usage: Optional[Dict[str, Any]] = None
    cost_nanos: Optional[StrictInt] = None
    currency: Optional[StrictStr] = None
    pricing_lines: Optional[List[Dict[str, Any]]] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["request_id", "team_id", "app_id", "app_title", "referer", "endpoint", "model_id", "provider", "native_response_id", "stream", "byok", "status_code", "success", "error_code", "error_message", "before", "execute", "latency_ms", "generation_ms", "usage", "cost_nanos", "currency", "pricing_lines"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayGenerationRecord from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayGenerationRecord from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "request_id": obj.get("request_id"),
            "team_id": obj.get("team_id"),
            "app_id": obj.get("app_id"),
            "app_title": obj.get("app_title"),
            "referer": obj.get("referer"),
            "endpoint": obj.get("endpoint"),
            "model_id": obj.get("model_id"),
            "provider": obj.get("provider"),
            "native_response_id": obj.get("native_response_id"),
            "stream": obj.get("stream"),
            "byok": obj.get("byok"),
            "status_code": obj.get("status_code"),
            "success": obj.get("success"),
            "error_code": obj.get("error_code"),
            "error_message": obj.get("error_message"),
            "before": obj.get("before"),
            "execute": obj.get("execute"),
            "latency_ms": obj.get("latency_ms"),
            "generation_ms": obj.get("generation_ms"),
            "usage": obj.get("usage"),
            "cost_nanos": obj.get("cost_nanos"),
            "currency": obj.get("currency"),
            "pricing_lines": obj.get("pricing_lines")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse

from ai_stats_generated.api_client import ApiClient, RequestSerialized
from ai_stats_generated.api_response import ApiResponse
from ai_stats_generated.rest import RESTResponseType


class CompletionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_chat_completion(
        self,
        chat_completions_request: ChatCompletionsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ChatCompletionsResponse:
        """Create a chat completion

        Routes a chat completion request to the healthiest configured provider for the requested model. The gateway normalises upstream responses and adds auditing metadata to the payload.

        :param chat_completions_request: (required)
        :type chat_completions_request: ChatCompletionsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_chat_completion_serialize(
            chat_completions_request=chat_completions_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChatCompletionsResponse",
            '400': "GatewayError",
            '401': "GatewayError",
            '402': "GatewayError",
            '404': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_chat_completion_with_http_info(
        self,
        chat_completions_request: ChatCompletionsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ChatCompletionsResponse]:
        """Create a chat completion

        Routes a chat completion request to the healthiest configured provider for the requested model. The gateway normalises upstream responses and adds auditing metadata to the payload.

        :param chat_completions_request: (required)
        :type chat_completions_request: ChatCompletionsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_chat_completion_serialize(
            chat_completions_request=chat_completions_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChatCompletionsResponse",
            '400': "GatewayError",
            '401': "GatewayError",
            '402': "GatewayError",
            '404': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_chat_completion_without_preload_content(
        self,
        chat_completions_request: ChatCompletionsRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create a chat completion

        Routes a chat completion request to the healthiest configured provider for the requested model. The gateway normalises upstream responses and adds auditing metadata to the payload.

        :param chat_completions_request: (required)
        :type chat_completions_request: ChatCompletionsRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_chat_completion_serialize(
            chat_completions_request=chat_completions_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChatCompletionsResponse",
            '400': "GatewayError",
            '401': "GatewayError",
            '402': "GatewayError",
            '404': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_chat_completion_serialize(
        self,
        chat_completions_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if chat_completions_request is not None:
            _body_params = chat_completions_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json', 
                    'text/event-stream'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'GatewayAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/chat/completions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# flake8: noqa

# import apis into api package
from ai_stats_generated.api.analytics_api import AnalyticsApi
from ai_stats_generated.api.completions_api import CompletionsApi
from ai_stats_generated.api.generations_api import GenerationsApi
from ai_stats_generated.api.images_api import ImagesApi
from ai_stats_generated.api.models_api import ModelsApi
from ai_stats_generated.api.moderations_api import ModerationsApi
from ai_stats_generated.api.video_api import VideoApi

